@@ -4,7 +4,7 @@
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include "kostore/koStore.h"
 #include "kostore/koStoreDevice.h"
 #include "k3bapplication.h"
+#include "k3binteractiondialog.h"
 
 #include <k3baudiodoc.h>
 #include <k3baudiodatasourceiterator.h>
@@ -107,6 +108,10 @@ void K3bProjectManager::addProject( K3bDoc* doc )
     kdDebug() << "(K3bProjectManager) adding doc " << doc->URL().path() << endl;
     
     d->projects.append(doc);
+
+    connect( doc, SIGNAL(changed(K3bDoc*)),
+	     this, SLOT(slotProjectChanged(K3bDoc*)) );
+
     emit newProject( doc );
   }
 }
@@ -180,7 +185,7 @@ void K3bProjectManager::setActive( K3bDoc* doc )
 }
 
 
-K3bDoc* K3bProjectManager::activeDoc() const
+K3bDoc* K3bProjectManager::activeProject() const
 {
   return d->activeProject;
 }
@@ -270,7 +275,20 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
 {
   KConfig* c = kapp->config();
 
-  c->setGroup( "default " + doc->typeString() + " settings" );
+  QString oldGroup = c->group();
+
+  QString cg = "default " + doc->typeString() + " settings";
+
+  // earlier K3b versions loaded the saved settings
+  // so that is what we do as a default
+  int i = KConfigGroup( c, "General Options" ).readNumEntry( "action dialog startup settings", 
+							     K3bInteractionDialog::LOAD_SAVED_SETTINGS );
+  if( i == K3bInteractionDialog::LOAD_K3B_DEFAULTS )
+    return; // the default k3b settings are the ones everyone starts with
+  else if( i == K3bInteractionDialog::LOAD_LAST_SETTINGS )
+    cg = "last used " + cg;
+
+  c->setGroup( cg );
 
   QString mode = c->readEntry( "writing_mode" );
   if ( mode == "dao" )
@@ -296,7 +314,7 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
   case K3bDoc::AUDIO: {
     K3bAudioDoc* audioDoc = static_cast<K3bAudioDoc*>(doc);
 
-    audioDoc->writeCdText( c->readBoolEntry( "cd_text", false ) );
+    audioDoc->writeCdText( c->readBoolEntry( "cd_text", true ) );
     audioDoc->setHideFirstTrack( c->readBoolEntry( "hide_first_track", false ) );
     audioDoc->setNormalize( c->readBoolEntry( "normalize", false ) );
     audioDoc->setAudioRippingParanoiaMode( c->readNumEntry( "paranoia mode", 0 ) );
@@ -329,11 +347,10 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
   }
 
   case K3bDoc::DATA:
-  case K3bDoc::DVD:
-  case K3bDoc::VIDEODVD: {
+  case K3bDoc::DVD: {
     K3bDataDoc* dataDoc = static_cast<K3bDataDoc*>(doc);
 
-    dataDoc->setIsoOptions( K3bIsoOptions::load( c ) );
+    dataDoc->setIsoOptions( K3bIsoOptions::load( c, false ) );
 
     QString datamode = c->readEntry( "data_track_mode" );
     if( datamode == "mode1" )
@@ -360,10 +377,18 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
     break;
   }
 
+  case K3bDoc::VIDEODVD: {
+    // the only defaults we need here are the volume id and stuff
+    K3bDataDoc* dataDoc = static_cast<K3bDataDoc*>(doc);
+    dataDoc->setIsoOptions( K3bIsoOptions::load( c, false ) );
+    dataDoc->setVerifyData( c->readBoolEntry( "verify data", false ) );
+    break;
+  }
+
   case K3bDoc::MIXED: {
     K3bMixedDoc* mixedDoc = static_cast<K3bMixedDoc*>(doc);
 
-    mixedDoc->audioDoc()->writeCdText( c->readBoolEntry( "cd_text", false ) );
+    mixedDoc->audioDoc()->writeCdText( c->readBoolEntry( "cd_text", true ) );
     mixedDoc->audioDoc()->setNormalize( c->readBoolEntry( "normalize", false ) );
 
     // load mixed type
@@ -382,10 +407,10 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
     else
       mixedDoc->dataDoc()->setDataMode( K3b::DATA_MODE_AUTO );
 
-    mixedDoc->dataDoc()->setIsoOptions( K3bIsoOptions::load( c ) );
+    mixedDoc->dataDoc()->setIsoOptions( K3bIsoOptions::load( c, false ) );
 
     if( mixedDoc->dataDoc()->isoOptions().volumeID().isEmpty() )
-      mixedDoc->dataDoc()->setVolumeID( doc->URL().path() );
+      mixedDoc->dataDoc()->setVolumeID( doc->URL().fileName() );
 
     break;
   }
@@ -401,7 +426,7 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
     vcdDoc->vcdOptions()->setPbcWaitTime( c->readNumEntry( "Time to wait after each Sequence/Segment", 2 ) );
 
     if( vcdDoc->vcdOptions()->volumeId().isEmpty() )
-      vcdDoc->vcdOptions()->setVolumeId( doc->URL().path() );
+      vcdDoc->vcdOptions()->setVolumeId( doc->URL().fileName() );
 
     break;
   }
@@ -413,10 +438,12 @@ void K3bProjectManager::loadDefaults( K3bDoc* doc )
       doc->type() == K3bDoc::VIDEODVD ||
       doc->type() == K3bDoc::DVD ) {
     if( static_cast<K3bDataDoc*>(doc)->isoOptions().volumeID().isEmpty() )
-      static_cast<K3bDataDoc*>(doc)->setVolumeID( doc->URL().path() );
+      static_cast<K3bDataDoc*>(doc)->setVolumeID( doc->URL().fileName() );
   }
 
   doc->setModified( false );
+
+  c->setGroup( oldGroup );
 }
 
 
@@ -550,6 +577,8 @@ K3bDoc* K3bProjectManager::openProject( const KURL& url )
     // FIXME: find a better way to tell everyone (especially the projecttabwidget)
     //        that the doc is not changed
     emit projectSaved( newDoc );
+
+    kdDebug() << "(K3bProjectManager) loading project done." << endl;
   }
   else {
     delete newDoc;
@@ -569,22 +598,6 @@ bool K3bProjectManager::saveProject( K3bDoc* doc, const KURL& url )
 
   bool success = false;
 
-  // for now we cannot save audio and mixed projects containing audio cd track sources
-  if( doc->type() == K3bDoc::AUDIO ||
-      doc->type() == K3bDoc::MIXED ) {
-    K3bAudioDataSourceIterator it( doc->type() == K3bDoc::AUDIO ?
-				   static_cast<K3bAudioDoc*>( doc ) :
-				   static_cast<K3bMixedDoc*>( doc )->audioDoc() );
-    while( it.current() ) {
-      if( dynamic_cast<K3bAudioCdTrackSource*>(it.current()) ) {
-	KMessageBox::sorry( qApp->mainWidget(), i18n("It is not yet possible to save projects containing audio CD track "
-						     "sources.") );
-	return false;
-      }
-      it.next();
-    }
-  }
-
   // create the store
   KoStore* store = KoStore::createStore( tmpfile, KoStore::Write, "application/x-k3b" );
   if( store ) {
@@ -632,4 +645,9 @@ bool K3bProjectManager::saveProject( K3bDoc* doc, const KURL& url )
 }
 
 
+void K3bProjectManager::slotProjectChanged( K3bDoc* doc )
+{
+  emit projectChanged( doc );
+}
+
 #include "k3bprojectmanager.moc"
